<template>
  <div class="bbsl-common-page">
    <div class="bbsl-content">
      <h6 class="title">积水设备统计分析</h6>
      <div class="content-box">
        <div class="content-box-item1">
          <div class="item-titel">
            <span>年统计</span>
          </div>
          <el-date-picker
            v-model="yearValue"
            value-format="yyyy"
            size="mini"
            type="year"
            @change="yearChange"
            placeholder="请选择年份"
          >
          </el-date-picker>
          <div id="yearStatus" class="full"></div>
        </div>
        <div class="content-box-item1">
          <div class="item-titel">
            <span>月统计</span>
          </div>
          <el-date-picker
            v-model="monthValue"
            value-format="yyyy-MM"
            size="mini"
            type="month"
            @change="monthChange"
            placeholder="请选择月份"
          >
          </el-date-picker>
          <div id="monthStatus" class="full"></div>
        </div>
      </div>
      <div class="content-box1">
        <div class="content-box-item1">
          <div class="item-titel">
            <span>日统计</span>
          </div>
          <el-date-picker
            v-model="dateValue"
            value-format="yyyy-MM-dd"
            size="mini"
            type="date"
            @change="dateChange"
            placeholder="请选择日期"
          >
          </el-date-picker>
          <div id="dateStatus" class="full"></div>
        </div>
      </div>
    </div>
  </div>
</template>
  
  <script>
import * as echarts from 'echarts'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import hydropsYear from '@/api/device/hydropsYear.js'
export default {
  components: {},
  data() {
    return {
      yearValue: '',
      dateValue: '',
      monthValue: '',
      dateTypes: [], //日期类型字典
      yearEchart: null,
      monthEchart: null,
      dateEchart: null,
      monthList: [],
      yearList: [],
      dateList: [],
    }
  },
  created() {
    this.dateTypes = dictUtils.getDictItemsFromCache('rqlx')
    this.initialize()
  },
  mounted() {
    this.yearEcharts()
    this.monthEcharts()
    this.dateEcharts()
    this.$root.$on('resize', () => {
      this.resize(500)
    })
  },
  methods: {
    resize(delay) {
      // 动态计算表格的高度，自适应当前容器
      setTimeout(() => {
        this.yearEchart.resize()
        this.monthEchart.resize()
        this.dateEchart.resize()
      }, delay || 0)
    },
    initialize() {
      var moment = require('moment') //打开时默认时间为一天前至获取当前年月日时分秒
      let monthTime = moment().format('YYYY-MM')
      let yearTime = moment(new Date()).format('YYYY')
      let dateTime = moment(new Date()).format('YYYY-MM-DD')
      this.yearValue = yearTime
      this.monthValue = monthTime
      this.dateValue = dateTime
      this.yearChange()
      this.monthChange()
      this.dateChange()
    },
    /**
     * @Echarts
     * */
    // 年统计
    yearEcharts() {
      let times = []
      let yNum = []
      //   this.yearList.forEach((e) => {
      //     times.push(e.time)
      //     yNum.push(e.waterLevel)
      //   })
      times.push(this.yearList.time)
      yNum.push(this.yearList.waterLevel)
      let chartDom = document.getElementById('yearStatus')
      this.yearEchart = echarts.init(chartDom)
      let option = {
        grid: {
          top: 35,
          left: 70, // 调整这个属性
        },
        xAxis: {
          type: 'category',
          data: times,
        },
        yAxis: {
          // name: '万m³',
          type: 'value',
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        series: [
          {
            data: yNum,
            type: 'bar',
          },
        ],
      }
      option && this.yearEchart.setOption(option)
      // 点击事件
      this.yearEchart.on('click', (parmas) => {
        console.log(parmas)
      })
    },
    // 月统计
    monthEcharts() {
      let times = []
      let yNum = []
      //   this.yearList.forEach((e) => {
      //     times.push(e.time)
      //     yNum.push(e.waterLevel)
      //   })
      times.push(this.monthList.time)
      yNum.push(this.monthList.waterLevel)
      let chartDom = document.getElementById('monthStatus')
      this.yearEchart = echarts.init(chartDom)
      let option = {
        grid: {
          top: 35,
          left: 70, // 调整这个属性
        },
        xAxis: {
          type: 'category',
          data: times,
        },
        yAxis: {
          // name: '万m³',
          type: 'value',
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        series: [
          {
            data: yNum,
            type: 'bar',
          },
        ],
      }
      option && this.yearEchart.setOption(option)
      // 点击事件
      this.yearEchart.on('click', (parmas) => {
        console.log(parmas)
      })
    },
    // 日统计
    dateEcharts() {
      let times = []
      let yNum = []
      //   this.yearList.forEach((e) => {
      //     times.push(e.time)
      //     yNum.push(e.waterLevel)
      //   })
      times.push(this.dateList.time)
      yNum.push(this.dateList.waterLevel)
      let chartDom = document.getElementById('dateStatus')
      this.yearEchart = echarts.init(chartDom)
      let option = {
        grid: {
          top: 35,
          left: 70, // 调整这个属性
        },
        xAxis: {
          type: 'category',
          data: times,
        },
        yAxis: {
          // name: '万m³',
          type: 'value',
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        series: [
          {
            data: yNum,
            type: 'bar',
          },
        ],
      }
      option && this.yearEchart.setOption(option)
      // 点击事件
      this.yearEchart.on('click', (parmas) => {
        console.log(parmas)
      })
    },
    /**
     * @请求
     * */
    yearChange(val) {
      console.log(val)
      let parmas = {
        dateType: '1',
        time: this.yearValue,
      }
      hydropsYear.loadQuery(parmas, (res) => {
        if (res.state) {
          this.yearList = res.value
          this.$nextTick(() => {
            this.yearEcharts()
          })
        }
      })
    },
    monthChange() {
      let parmas = {
        dateType: '2',
        time: this.monthValue,
      }
      hydropsYear.loadQuery(parmas, (res) => {
        if (res.state) {
          this.monthList = res.value
          this.$nextTick(() => {
            this.monthEcharts()
          })
        }
      })
    },
    dateChange() {
      let parmas = {
        dateType: '3',
        time: this.dateTime,
      }
      hydropsYear.loadQuery(parmas, (res) => {
        if (res.state) {
          this.dateList = res.value
          this.$nextTick(() => {
            this.dateEcharts()
          })
        }
      })
    },
  },
}
</script>
  
  <style lang="scss" scoped>
.full {
  height: calc(100% - 50px);
}

.bbsl-content {
  height: 100%;
  padding: 20px 20px;
  background-color: #fff;
  box-shadow: 0px 0px 12px 0 rgba($color: #000000, $alpha: 0.1);
  position: relative;
  overflow: auto;

  .title {
    padding: 0% !important;
    margin: 0% !important;
    color: #409eff;
    font-size: 20px !important;
    font-weight: 700;
  }

  .content-box1 {
    width: 100%;
    height: 60%;
    display: flex;
    justify-content: flex-start;

    .content-box-item1 {
      height: 100%;
      width: 100%;

      .full {
        height: 80%;
        width: 100%;
      }

      .item-titel {
        padding: 10px 0;
        color: #409eff;
        font-size: 20px !important;
        font-weight: 700;
      }
    }
  }

  .content-box {
    width: 100%;
    height: 50%;
    display: flex;
    justify-content: flex-start;

    .content-box-item1 {
      height: 100%;
      width: 48%;

      .item-titel {
        padding: 10px 0;
        color: #409eff;
        font-size: 20px !important;
        font-weight: 700;
      }
    }

    .content-box-item {
      height: 100%;
      width: 48%;

      .title {
        padding: 10px 0;
        color: #409eff;
        font-size: 20px !important;
        font-weight: 700;
      }

      .item-titel {
        padding: 10px 0;
        color: #409eff;
        font-size: 20px !important;
        font-weight: 700;
      }
    }
  }
}
</style>
  